Re: [PATCH 04/12] be2iscsi: Rename MCC and BMBX processing functions

2016-02-01 Thread kbuild test robot
Hi Jitendra,

[auto build test ERROR on scsi/for-next]
[also build test ERROR on next-20160201]
[cannot apply to v4.5-rc2]
[if your patch is applied to the wrong git tree, please drop us a note to help 
improving the system]

url:
https://github.com/0day-ci/linux/commits/Jitendra-Bhivare/be2iscsi-critical-fixes-for-11-0-0-0/20160201-181716
base:   https://git.kernel.org/pub/scm/linux/kernel/git/jejb/scsi.git for-next
config: x86_64-randconfig-s1-02011933 (attached as .config)
reproduce:
# save the attached .config to linux build tree
make ARCH=x86_64 

Note: the 
linux-review/Jitendra-Bhivare/be2iscsi-critical-fixes-for-11-0-0-0/20160201-181716
 HEAD 7dd8e579ae5fffda523c8c75978134fe99d5aa68 builds fine.
  It only hurts bisectibility.

All errors (new ones prefixed by >>):

   drivers/scsi/be2iscsi/be_cmds.c: In function 'be_mbox_notify_wait':
>> drivers/scsi/be2iscsi/be_cmds.c:716:12: error: implicit declaration of 
>> function 'be_mcc_compl_process' [-Werror=implicit-function-declaration]
  status = be_mcc_compl_process(ctrl, &mbox->compl);
   ^
   cc1: some warnings being treated as errors

vim +/be_mcc_compl_process +716 drivers/scsi/be2iscsi/be_cmds.c

ea53ed97 Jitendra Bhivare2016-02-01  710status = 
be_mbox_db_ready_poll(ctrl);
bfead3b2 Jayamohan Kallickal 2009-10-23  711if (status != 0)
bfead3b2 Jayamohan Kallickal 2009-10-23  712return status;
bfead3b2 Jayamohan Kallickal 2009-10-23  713  
bfead3b2 Jayamohan Kallickal 2009-10-23  714/* A cq entry has been made now 
*/
bfead3b2 Jayamohan Kallickal 2009-10-23  715if (be_mcc_compl_is_new(compl)) 
{
bfead3b2 Jayamohan Kallickal 2009-10-23 @716status = 
be_mcc_compl_process(ctrl, &mbox->compl);
bfead3b2 Jayamohan Kallickal 2009-10-23  717be_mcc_compl_use(compl);
bfead3b2 Jayamohan Kallickal 2009-10-23  718if (status)
bfead3b2 Jayamohan Kallickal 2009-10-23  719return status;

:: The code at line 716 was first introduced by commit
:: bfead3b2cb4607c71831423c3ee97d22cd0c9dcb [SCSI] be2iscsi: Adding msix 
and mcc_rings V3

:: TO: Jayamohan Kallickal 
:: CC: James Bottomley 

---
0-DAY kernel test infrastructureOpen Source Technology Center
https://lists.01.org/pipermail/kbuild-all   Intel Corporation


.config.gz
Description: Binary data


Re: [PATCH 04/12] be2iscsi: Rename MCC and BMBX processing functions

2016-02-01 Thread Johannes Thumshirn
On Mon, Feb 01, 2016 at 03:42:43PM +0530, Jitendra Bhivare wrote:
> beiscsi_mccq_compl -> beiscsi_mccq_compl_wait - indicate blocking call.
> be_mcc_wait_compl -> be_mcc_compl_poll - indicate polling for completion.
> be_mbox_db_ready_wait -> be_mbox_db_ready_poll - indicate polling for RDY.
> be_mcc_compl_process -> beiscsi_process_mbox_compl - indicate BMBX compl.
> 
> Signed-off-by: Jitendra Bhivare 
> ---
>  drivers/scsi/be2iscsi/be_cmds.c  | 35 +--
>  drivers/scsi/be2iscsi/be_cmds.h  |  6 +++---
>  drivers/scsi/be2iscsi/be_iscsi.c |  8 
>  drivers/scsi/be2iscsi/be_main.c  |  8 
>  drivers/scsi/be2iscsi/be_mgmt.c  | 12 ++--
>  5 files changed, 34 insertions(+), 35 deletions(-)
> 
> diff --git a/drivers/scsi/be2iscsi/be_cmds.c b/drivers/scsi/be2iscsi/be_cmds.c
> index fa010ac..8dd8521 100644
> --- a/drivers/scsi/be2iscsi/be_cmds.c
> +++ b/drivers/scsi/be2iscsi/be_cmds.c
> @@ -140,7 +140,7 @@ unsigned int alloc_mcc_tag(struct beiscsi_hba *phba)
>  }
>  
>  /*
> - * beiscsi_mccq_compl()- Wait for completion of MBX
> + * beiscsi_mccq_compl_wait()- Process completion in MCC CQ
>   * @phba: Driver private structure
>   * @tag: Tag for the MBX Command
>   * @wrb: the WRB used for the MBX Command
> @@ -152,9 +152,9 @@ unsigned int alloc_mcc_tag(struct beiscsi_hba *phba)
>   * Success: 0
>   * Failure: Non-Zero
>   **/
> -int beiscsi_mccq_compl(struct beiscsi_hba *phba,
> - uint32_t tag, struct be_mcc_wrb **wrb,
> - struct be_dma_mem *mbx_cmd_mem)
> +int beiscsi_mccq_compl_wait(struct beiscsi_hba *phba,
> + uint32_t tag, struct be_mcc_wrb **wrb,
> + struct be_dma_mem *mbx_cmd_mem)
>  {
>   int rc = 0;
>   uint32_t mcc_tag_status;
> @@ -283,7 +283,7 @@ static inline void be_mcc_compl_use(struct be_mcc_compl 
> *compl)
>  }
>  
>  /*
> - * be_mcc_compl_process()- Check the MBX comapletion status
> + * beiscsi_process_mbox_compl()- Check the MBX completion status
>   * @ctrl: Function specific MBX data structure
>   * @compl: Completion status of MBX Command
>   *
> @@ -293,8 +293,8 @@ static inline void be_mcc_compl_use(struct be_mcc_compl 
> *compl)
>   * Success: Zero
>   * Failure: Non-Zero
>   **/
> -static int be_mcc_compl_process(struct be_ctrl_info *ctrl,
> - struct be_mcc_compl *compl)
> +static int beiscsi_process_mbox_compl(struct be_ctrl_info *ctrl,
> +   struct be_mcc_compl *compl)
>  {
>   u16 compl_status, extd_status;
>   struct be_mcc_wrb *wrb = wrb_from_mbox(&ctrl->mbox_mem);
> @@ -520,7 +520,7 @@ int beiscsi_process_mcc_compl(struct be_ctrl_info *ctrl,
>  }
>  
>  /*
> - * be_mcc_wait_compl()- Wait for MBX completion
> + * be_mcc_compl_poll()- Wait for MBX completion
>   * @phba: driver private structure
>   *
>   * Wait till no more pending mcc requests are present
> @@ -556,8 +556,7 @@ int be_mcc_compl_poll(struct beiscsi_hba *phba, unsigned 
> int tag)
>  }
>  
>  /*
> -/*
> - * be_mbox_db_ready_wait()- Check ready status
> + * be_mbox_db_ready_poll()- Check ready status
>   * @ctrl: Function specific MBX data structure
>   *
>   * Check for the ready status of FW to send BMBX
> @@ -567,7 +566,7 @@ int be_mcc_compl_poll(struct beiscsi_hba *phba, unsigned 
> int tag)
>   * Success: 0
>   * Failure: Non-Zero
>   **/
> -static int be_mbox_db_ready_wait(struct be_ctrl_info *ctrl)
> +static int be_mbox_db_ready_poll(struct be_ctrl_info *ctrl)
>  {
>   /* wait 30s for generic non-flash MBOX operation */
>  #define BEISCSI_MBX_RDY_BIT_TIMEOUT  3
> @@ -629,7 +628,7 @@ int be_mbox_notify(struct be_ctrl_info *ctrl)
>   struct be_mcc_compl *compl = &mbox->compl;
>   struct beiscsi_hba *phba = pci_get_drvdata(ctrl->pdev);
>  
> - status = be_mbox_db_ready_wait(ctrl);
> + status = be_mbox_db_ready_poll(ctrl);
>   if (status)
>   return status;
>  
> @@ -638,7 +637,7 @@ int be_mbox_notify(struct be_ctrl_info *ctrl)
>   val |= (upper_32_bits(mbox_mem->dma) >> 2) << 2;
>   iowrite32(val, db);
>  
> - status = be_mbox_db_ready_wait(ctrl);
> + status = be_mbox_db_ready_poll(ctrl);
>   if (status)
>   return status;
>  
> @@ -648,7 +647,7 @@ int be_mbox_notify(struct be_ctrl_info *ctrl)
>   val |= (u32) (mbox_mem->dma >> 4) << 2;
>   iowrite32(val, db);
>  
> - status = be_mbox_db_ready_wait(ctrl);
> + status = be_mbox_db_ready_poll(ctrl);
>   if (status)
>   return status;
>  
> @@ -656,7 +655,7 @@ int be_mbox_notify(struct be_ctrl_info *ctrl)
>   udelay(1);
>  
>   if (be_mcc_compl_is_new(compl)) {
> - status = be_mcc_compl_process(ctrl, &mbox->compl);
> + status = beiscsi_process_mbox_compl(ctrl, compl);
>   be_mcc_compl_use(compl);
>   if (status) {
>   beiscsi_log(phba, KERN_ERR,
> @@ -689,7 +688,7 @@ static int be_mbox_notify_wa

[PATCH 04/12] be2iscsi: Rename MCC and BMBX processing functions

2016-02-01 Thread Jitendra Bhivare
beiscsi_mccq_compl -> beiscsi_mccq_compl_wait - indicate blocking call.
be_mcc_wait_compl -> be_mcc_compl_poll - indicate polling for completion.
be_mbox_db_ready_wait -> be_mbox_db_ready_poll - indicate polling for RDY.
be_mcc_compl_process -> beiscsi_process_mbox_compl - indicate BMBX compl.

Signed-off-by: Jitendra Bhivare 
---
 drivers/scsi/be2iscsi/be_cmds.c  | 35 +--
 drivers/scsi/be2iscsi/be_cmds.h  |  6 +++---
 drivers/scsi/be2iscsi/be_iscsi.c |  8 
 drivers/scsi/be2iscsi/be_main.c  |  8 
 drivers/scsi/be2iscsi/be_mgmt.c  | 12 ++--
 5 files changed, 34 insertions(+), 35 deletions(-)

diff --git a/drivers/scsi/be2iscsi/be_cmds.c b/drivers/scsi/be2iscsi/be_cmds.c
index fa010ac..8dd8521 100644
--- a/drivers/scsi/be2iscsi/be_cmds.c
+++ b/drivers/scsi/be2iscsi/be_cmds.c
@@ -140,7 +140,7 @@ unsigned int alloc_mcc_tag(struct beiscsi_hba *phba)
 }
 
 /*
  * beiscsi_mccq_compl()- Wait for completion of MBX
  * @phba: Driver private structure
  * @tag: Tag for the MBX Command
  * @wrb: the WRB used for the MBX Command
@@ -152,9 +152,9 @@ unsigned int alloc_mcc_tag(struct beiscsi_hba *phba)
  * Success: 0
  * Failure: Non-Zero
  **/
-int beiscsi_mccq_compl(struct beiscsi_hba *phba,
-   uint32_t tag, struct be_mcc_wrb **wrb,
-   struct be_dma_mem *mbx_cmd_mem)
+int beiscsi_mccq_compl_wait(struct beiscsi_hba *phba,
+   uint32_t tag, struct be_mcc_wrb **wrb,
+   struct be_dma_mem *mbx_cmd_mem)
 {
int rc = 0;
uint32_t mcc_tag_status;
@@ -283,7 +283,7 @@ static inline void be_mcc_compl_use(struct be_mcc_compl 
*compl)
 }
 
 /*
  * be_mcc_compl_process()- Check the MBX comapletion status
  * @ctrl: Function specific MBX data structure
  * @compl: Completion status of MBX Command
  *
@@ -293,8 +293,8 @@ static inline void be_mcc_compl_use(struct be_mcc_compl 
*compl)
  * Success: Zero
  * Failure: Non-Zero
  **/
-static int be_mcc_compl_process(struct be_ctrl_info *ctrl,
-   struct be_mcc_compl *compl)
+static int beiscsi_process_mbox_compl(struct be_ctrl_info *ctrl,
+ struct be_mcc_compl *compl)
 {
u16 compl_status, extd_status;
struct be_mcc_wrb *wrb = wrb_from_mbox(&ctrl->mbox_mem);
@@ -520,7 +520,7 @@ int beiscsi_process_mcc_compl(struct be_ctrl_info *ctrl,
 }
 
 /*
  * be_mcc_wait_compl()- Wait for MBX completion
  * @phba: driver private structure
  *
  * Wait till no more pending mcc requests are present
@@ -556,8 +556,7 @@ int be_mcc_compl_poll(struct beiscsi_hba *phba, unsigned 
int tag)
 }
 
 /*
 /*
  * be_mbox_db_ready_wait()- Check ready status
  * @ctrl: Function specific MBX data structure
  *
  * Check for the ready status of FW to send BMBX
@@ -567,7 +566,7 @@ int be_mcc_compl_poll(struct beiscsi_hba *phba, unsigned 
int tag)
  * Success: 0
  * Failure: Non-Zero
  **/
-static int be_mbox_db_ready_wait(struct be_ctrl_info *ctrl)
+static int be_mbox_db_ready_poll(struct be_ctrl_info *ctrl)
 {
/* wait 30s for generic non-flash MBOX operation */
 #define BEISCSI_MBX_RDY_BIT_TIMEOUT3
@@ -629,7 +628,7 @@ int be_mbox_notify(struct be_ctrl_info *ctrl)
struct be_mcc_compl *compl = &mbox->compl;
struct beiscsi_hba *phba = pci_get_drvdata(ctrl->pdev);
 
-   status = be_mbox_db_ready_wait(ctrl);
+   status = be_mbox_db_ready_poll(ctrl);
if (status)
return status;
 
@@ -638,7 +637,7 @@ int be_mbox_notify(struct be_ctrl_info *ctrl)
val |= (upper_32_bits(mbox_mem->dma) >> 2) << 2;
iowrite32(val, db);
 
-   status = be_mbox_db_ready_wait(ctrl);
+   status = be_mbox_db_ready_poll(ctrl);
if (status)
return status;
 
@@ -648,7 +647,7 @@ int be_mbox_notify(struct be_ctrl_info *ctrl)
val |= (u32) (mbox_mem->dma >> 4) << 2;
iowrite32(val, db);
 
-   status = be_mbox_db_ready_wait(ctrl);
+   status = be_mbox_db_ready_poll(ctrl);
if (status)
return status;
 
@@ -656,7 +655,7 @@ int be_mbox_notify(struct be_ctrl_info *ctrl)
udelay(1);
 
if (be_mcc_compl_is_new(compl)) {
-   status = be_mcc_compl_process(ctrl, &mbox->compl);
+   status = beiscsi_process_mbox_compl(ctrl, compl);
be_mcc_compl_use(compl);
if (status) {
beiscsi_log(phba, KERN_ERR,
@@ -689,7 +688,7 @@ static int be_mbox_notify_wait(struct beiscsi_hba *phba)
struct be_mcc_compl *compl = &mbox->compl;
struct be_ctrl_info *ctrl = &phba->ctrl;
 
-   status = be_mbox_db_ready_wait(ctrl);
+   status = be_mbox_db_ready_poll(ctrl);
@@ -140,7 +140,7 @@ unsigned int alloc_mcc_tag(struct beiscsi_hba *phba)
 
 /*
- * beiscsi_mccq_compl()- Wait for completion of MBX
+ * beiscsi_mccq_compl_wait()- Process completion in MCC CQ
  * @phba: Driver private structure
  * @tag: Tag for the MBX Command
@@ -283,7 +283,7 @@ static inline void be_mcc_compl_use(struct be_mcc_compl 
 
 /*
- * be_mcc_compl_process()- Check the MBX comapletion status
+ * beiscsi_process_mbox_compl()- Check the MBX completion status
  * @ctrl: Function specific MBX data structure
  * @compl: Completion status of MBX Command
@@ -520,7 +520,7 @@ int beiscsi_process_mcc_compl(struct be_ctrl_info *ctrl,
 
 /*
- * be_mcc_wait_compl()- Wait for MBX completion
+ * be_mcc_compl_poll()- Wait for MBX completion
  * @phba: driver private structure
  *
@@ -556,8 +556,7 @@ int be_mcc_compl_poll(struct beiscsi_hba *phba, unsigned 
 
 /*
-/*
- * be_mbox_db_ready_wait()- Check ready status
+ * be_mbox_db_ready_poll()- Check ready status
  * @ctrl: Function specific MBX data structure
  *
if (status)